@@ -4,10 +4,10 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef KNSBACKEND_H
-#define KNSBACKEND_H
+#pragma once
 
-#include <KNSCore/EntryInternal>
+#include <KNSCore/EngineBase>
+#include <KNSCore/Entry>
 #include <KNSCore/ErrorCode>
 
 #include "Transaction/AddonList.h"
@@ -16,13 +16,9 @@
 
 class KNSReviews;
 class KNSResource;
+class KNSResultsStream;
 class StandardBackendUpdater;
 
-namespace KNSCore
-{
-class Engine;
-}
-
 class DISCOVERCOMMON_EXPORT KNSBackend : public AbstractResourcesBackend
 {
     Q_OBJECT
@@ -51,7 +47,12 @@ public:
 
     bool isValid() const override;
 
-    QStringList extends() const override
+    bool extends(const QString &id) const override
+    {
+        return m_extends.contains(id);
+    }
+
+    QStringList extends() const
     {
         return m_extends;
     }
@@ -61,7 +62,7 @@ public:
         return m_iconName;
     }
 
-    KNSCore::Engine *engine() const
+    KNSCore::EngineBase *engine() const
     {
         return m_engine;
     }
@@ -69,36 +70,26 @@ public:
     void checkForUpdates() override;
 
     QString displayName() const override;
+    KNSResource *resourceForEntry(const KNSCore::Entry &entry);
 
 Q_SIGNALS:
-    void receivedResources(const QVector<AbstractResource *> &resources);
-    void searchFinished();
-    void startingSearch();
-    void availableForQueries();
     void initialized();
 
 public Q_SLOTS:
-    void receivedEntries(const KNSCore::EntryInternal::List &entries);
-    void statusChanged(const KNSCore::EntryInternal &entry);
-    void detailsLoaded(const KNSCore::EntryInternal &entry);
+    void statusChanged(const KNSCore::Entry &entry);
+    void detailsLoaded(const KNSCore::Entry &entry);
     void slotErrorCode(const KNSCore::ErrorCode &errorCode, const QString &message, const QVariant &metadata);
-    void slotEntryEvent(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::EntryEvent event);
+    void slotEntryEvent(const KNSCore::Entry &entry, KNSCore::Entry::EntryEvent event);
 
 private:
     void fetchInstalled();
-    KNSResource *resourceForEntry(const KNSCore::EntryInternal &entry);
     void setFetching(bool f);
     void markInvalid(const QString &message);
-    void searchStream(ResultsStream *stream, const QString &searchText);
-    void fetchMore();
-    void setResponsePending(bool pending);
+    KNSResultsStream *searchStream(const QString &searchText);
 
-    bool m_onePage = false;
-    bool m_responsePending = false;
-    QString m_pendingSearchQuery;
     bool m_fetching;
     bool m_isValid;
-    KNSCore::Engine *m_engine;
+    KNSCore::EngineBase *m_engine;
     QHash<QString, AbstractResource *> m_resourcesByName;
     KNSReviews *const m_reviews;
     QString m_name;
@@ -111,5 +102,3 @@ private:
     bool m_initialized = false;
     bool m_hasApplications = false;
 };
-
-#endif // KNSBACKEND_H
