@@ -20,6 +20,8 @@
 #include <appstream/AppStreamUtils.h>
 #include <utils.h>
 
+using namespace Qt::StringLiterals;
+
 QDebug operator<<(QDebug debug, const QSnapdPlug &plug)
 {
     QDebugStateSaver saver(debug);
@@ -60,10 +62,10 @@ QDebug operator<<(QDebug debug, const QSnapdSlot *slot)
     return debug;
 }
 
-const QStringList SnapResource::m_objects({QStringLiteral("qrc:/qml/PermissionsButton.qml")
+const QStringList SnapResource::m_topObjects({QStringLiteral("qrc:/qml/PermissionsButton.qml")
 #ifdef SNAP_CHANNELS
-                                               ,
-                                           QStringLiteral("qrc:/qml/ChannelsButton.qml")
+                                                  ,
+                                              QStringLiteral("qrc:/qml/ChannelsButton.qml")
 #endif
 });
 
@@ -264,7 +266,7 @@ void SnapResource::fetchChangelog()
 
 void SnapResource::fetchScreenshots()
 {
-    QList<QUrl> screenshots;
+    Screenshots screenshots;
 #ifdef SNAP_MEDIA
     for (int i = 0, c = m_snap->mediaCount(); i < c; ++i) {
         QScopedPointer<QSnapdMedia> media(m_snap->media(i));
@@ -277,7 +279,7 @@ void SnapResource::fetchScreenshots()
         screenshots << QUrl(screenshot->url());
     }
 #endif
-    Q_EMIT screenshotsFetched(screenshots, screenshots);
+    Q_EMIT screenshotsFetched(screenshots);
 }
 
 void SnapResource::invokeApplication() const
@@ -287,7 +289,7 @@ void SnapResource::invokeApplication() const
 
 AbstractResource::Type SnapResource::type() const
 {
-    return m_snap->snapType() != QLatin1String("app") ? Application : Technical;
+    return m_snap->snapType() != QSnapdEnums::SnapTypeApp ? Application : Technical;
 }
 
 void SnapResource::setSnap(const QSharedPointer<QSnapdSnap> &snap)
@@ -392,7 +394,7 @@ private:
         req->runSync();
         if (req->error()) {
             qWarning() << "snapd error" << req->errorString();
-            Q_EMIT error(new InlineMessage(InlineMessage::Error, "error", req->errorString()));
+            Q_EMIT error(new InlineMessage(InlineMessage::Error, u"error"_s, req->errorString()));
         }
         return req->error() == QSnapdRequest::NoError;
     }
